# -*- coding: utf-8 -*-

from django.conf import settings
from django.conf.urls import url, include

from rest_framework import response, views, permissions, renderers

try:
    from rest_framework_swagger import renderers as swagger
except ImportError:
    swagger = None

from autodoc.schemas import OpenAPISchemaGenerator


class SchemaView(views.APIView):
    renderer_classes = [
        renderers.JSONRenderer,
    ]

    if swagger:
        renderer_classes.append(swagger.SwaggerUIRenderer)

    permission_classes = [
        permissions.AllowAny,
    ]
    title = 'API documentation'
    prefix = '/'
    urlconf = settings.ROOT_URLCONF
    contact = None

    def get_contact(self):
        if self.contact is None:
            if settings.ADMINS:
                contact = settings.ADMINS[0]
        else:
            contact = self.contact

        if isinstance(contact, dict):
            return contact
        if isinstance(contact, tuple) and len(contact) == 2:
            name, email = contact
            return {'name': name, 'email': email}
        return {}

    def get_schema_generator(self):
        return OpenAPISchemaGenerator(
            urlconf=self.urlconf,
            url=self.prefix,
            info={
                'title': self.title,
                'contact': self.get_contact(),
                'version': '1.0',
            }
        )

    def get(self, request, *args, **kw):
        generator = self.get_schema_generator()
        schema = generator.get_schema(request=request)
        return response.Response(schema)
